# Configures sshguard.  If autoupgrade is true, will automatically upgrade
# the package.  Separate parameters for whitelist networks and hosts so
# that callers don't have to manually transform the hosts; use either one
# or both depending on your site's needs.
#
# Requires modules: freebsd (for FreeBSD support)
class sshguard ($ensure = 'present',
		$autoupgrade = $sshguard::defaults::autoupgrade,
		$package = $sshguard::defaults::package_name,
		$service = $sshguard::defaults::service_name,
		$watch_logs = $sshguard::defaults::watch_logs, # -l ...
		$safety_thresh = $sshguard::defaults::safety_thresh, # -a
		$pardon_min_interval = $sshguard::defaults::pardon_min_interval, # -p
		$prescribe_interval = $sshguard::defaults::prescribe_interval, # -s
		$whitelist_file = $sshguard::defaults::whitelist_file,
		$whitelist_dir = $sshguard::defaults::whitelist_dir,
		$whitelist_nets = [], $whitelist_hosts = [])
	inherits sshguard::defaults {
  if $ensure == 'present' {
    $pkg_ensure  = $autoupgrade ? { true => 'latest', default => 'present' }
    $file_ensure = 'present'
    $dir_ensure  = 'directory'
    $svc_ensure  = 'running'
    $rc_ensure   = 'present'
  } else {
    $pkg_ensure  = $ensure
    $file_ensure = 'absent'
    $dir_ensure  = 'absent'
    $svc_ensure  = 'stopped'
    $rc_ensure   = 'absent'
  }

  package { 'sshguard':
    name   => $package,
    ensure => $pkg_ensure,
    notify => Service['sshguard'],
  }

  service { 'sshguard':
    name       => $service,
    ensure     => $svc_ensure,
    hasrestart => true,
    require    => [Package['sshguard'], File[$whitelist_file]],
  }

  if $whitelist_dir {
    file { $whitelist_dir:
      ensure  => $dir_ensure,
      owner   => root,
      group   => 0,
      mode    => 0755,
      force   => true,
      require => Package['sshguard'],
      before  => File[$whitelist_file],
    }
  }

  file { $whitelist_file:
    ensure  => $file_ensure,
    owner   => root,
    group   => 0,
    mode    => 0755,
    content => template('sshguard/whitelist.erb'),
    require => Package['sshguard'],
    notify  => Service['sshguard'],
  }

  # Allow monit to monitor this service, if it is being used.
  # Make sure monit doesn't try to restart sshguard when it has
  # been removed.
  @monit::monitor {'sshguard':
    pidfile => '/var/run/sshguard.pid',
    ensure  => $file_ensure,
    tag     => 'default',
  }

  # OS-specific stuff
  if $::osfamily == 'Debian' {
    file { '/etc/default/sshguard':
      ensure  => $file_ensure,
      owner   => root,
      group   => root,
      content => template('sshguard/etc_default_sshguard.erb'),
      notify  => Service['sshguard'],
      before  => Service['sshguard'],
    }
  }

  if $::osfamily == 'FreeBSD' {
    case $package {
      /-ipfw$/: {
        require freebsd::ipfw
      }
      /-pf$/: {
        require freebsd::pf
      }
    }
    Service['firewall'] -> Service['sshguard']

    Freebsd::Rc_conf { # defaults
      ensure => $rc_ensure,
      before => Service['sshguard'],
      notify => Service['sshguard'],
    }

    freebsd::rc_conf {
      'sshguard_watch_logs':          value => join($watch_logs, ':');
      'sshguard_safety_thresh':       value => $safety_thresh;
      'sshguard_pardon_min_interval': value => $pardon_min_interval;
      'sshguard_prescribe_interval':  value => $prescribe_interval
    }
    # Old sshguard package used different config style.
    freebsd::rc_conf {'sshguard_flags': ensure => absent, value => ''}
  }
}
